function [G, C] = make_observation_and_corruption_graph(n, p, q)

% This function makes the graph of observations and the graph of corrupted observations
% Both are return as the upper triangular part of an adjacency matrix

% Input:
%
% n - number of points
% p - probability of any edge being measured
% q - probability any measured being corrupted

% Output:
%
% G - n x n - upper triangular part of adjacency matrix of measurement graph
% C - n x n - upper triangular part of adjacency matrix of corruption grap
%             all corrupted edges must also belong to G


%% Build Erdos-Renyi graph of probability p
G = triu(rand(n) < p, 1);     % Only upper triangular part is needed

%% Build corruptions graph (each edge in G corrupted with probability q)
C = G & triu(rand(n) < q, 1);

